@@ -8,7 +8,7 @@ import os
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
-API_GW = "https://86iu7tieha.execute-api.us-east-2.amazonaws.com/api/"
+API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -24,7 +24,7 @@ class FileType(enum.Enum):
     Code = 4
     Inputs = 5
 
-def create_training_job(local_train_data, local_test_data, entry_point, inputs_folder, hyper_param:dict):
+def create_training_job(local_train_data, local_test_data, entry_point, inputs_folder, hyper_param):
 
     # create job id
 
@@ -85,13 +85,19 @@ def get_zipfile(dirpath,outpath):
 	:outpath: dest
 	"""
 
-	zip = zipfile.ZipFile(outpath, "w", zipfile.ZIP_DEFLATED)
+	zip = zipfile.ZipFile(outpath, "w", zipfile.ZIP_STORED)
 	for path, dirnames, filenames in os.walk(dirpath):
 		fpath = path.replace(dirpath, '')
 		for filename in filenames:
 			zip.write(os.path.join(path, filename), os.path.join(fpath,filename))
 	zip.close()
 
+def folder_upload(dirpath):
+    jobid = str(uuid.uuid4())
+    for path, dirnames, filenames in os.walk(dirpath):
+        #fpath = path.replace(dirpath, '')
+        for filename in filenames:
+            __upload_one_file(jobid, FileType.Inputs.name, os.path.join(path,filename))
 
 ##############################################
 # Helpers
@@ -113,7 +119,8 @@ def __upload_one_file(job_id, type, object_name):
     # If successful, returns HTTP status code 204
     print(f'File upload HTTP status code: {http_response.status_code}')
 
-
 if __name__ == "__main__":
     # __upload_one_file(uuid.uuid4(), "code", "buffer1.txt")
-    create_training_job("buffer1.txt", "buffer1.txt", "buffer1.txt", None, {"epoch":"10"})
\ No newline at end of file
+    #create_training_job("buffer1.txt", "buffer1.txt", "buffer1.txt", None, {"epoch":"10"})
+    #get_zipfile("./test","./test.zip")
+    folder_upload("test")
\ No newline at end of file
